clear; clc; close all;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Name: Ogaga Odele
%Description: This MATLAB script solves the Schrodinger equation with a
%quartic potential for different energy values and plots the wavefunction 
%as a function of z. I have listed the lowest energy eigenvalue (epsilon = 
%1.0603) and two other energy eigenvalues (epsilon = 7.4554 & 16.2612) in 
%the script; the energy eigenvalues are accurate up to 4 significant 
%figures and better accuracy can be obtained by using a smaller step size 
%in the variable z. 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%Definition of variables
eps = 1.06029542713; %lowest energy eigenvalue
%eps = 7.455354817; %another energy eigenvalue
%eps = 16.261210045; %another energy eigenvalue 
%eps = 26.5275828;
z = 0:0.0001:4.5; %Creates vector of the variable z 
psi = zeros(1, length(z)); %Creates vector of the variable psi
psi_prime = zeros(1, length(z)); %Creates vector of the variable psi_prime

%Boundary condition (Initial values of psi and psi')
psi(1) = 1;
psi_prime(1) = 0;

%Solve differential equation for psi using Euler method
for i = 2:1:length(z)
    psi_prime(i) = psi_prime(i-1) + (z(i)-z(i-1))*(z(i-1)^4-eps)*psi(i-1);
    psi(i) = psi(i-1) + (z(i)-z(i-1))*psi_prime(i-1);
end

%Plot result 
figure;
plot(z, psi, 'Linewidth', 3);
hold on;
plot(-z, psi, 'Linewidth', 3); %wavefunction is symmetric so I plot for -z
set(gca,'FontSize',18,'FontName','Times');
xlabel('z'); ylabel('\psi(z)');
xlim([-4 4]);
hold off;
